/* eslint-env jest */

const { runPlugins } = require('./helpers');

const functionPlugin_ = require('../function');
const functionPlugin = x =>
  functionPlugin_(x, { transform: x => `token(${x})` });

it('ignores function calls with invalid tokens', () => {
  const actual = runPlugins(
    `
    background: url($color-brand);
  `,
    [functionPlugin([])]
  );
  expect(actual).toMatchSnapshot();
});

it('replaces function calls with valid tokens', () => {
  const actual = runPlugins(
    `
    background: url($color-brand);
  `,
    [functionPlugin(['color-brand'])]
  );
  expect(actual).toMatchSnapshot();
});

it('replaces multiple function calls', () => {
  const actual = runPlugins(
    `
    background: url($color-brand), linear-gradient($color-brand), rgba(0, 0, 0, $color-brand);
  `,
    [functionPlugin(['color-brand'])]
  );
  expect(actual).toMatchSnapshot();
});

it('removes interpolation inside calc', () => {
  const actual = runPlugins(
    `
    padding: calc(#{$color-brand} - #{$color-brand});
  `,
    [functionPlugin(['color-brand'])]
  );
  expect(actual).toMatchSnapshot();
});

it('removes interpolation inside complex calc', () => {
  const actual = runPlugins(
    `
    padding: calc(#{$color-brand} - (#{$color-brand} * 2));
  `,
    [functionPlugin(['color-brand'])]
  );
  expect(actual).toEqual(
    `
    padding: token("calc("+#{colorBrand}+" - ("+#{colorBrand}+" * 2))");
  `
  );
});

it('ignores non-css functions', () => {
  const actual = runPlugins(
    `
    padding: myfn($color-brand);
  `,
    [functionPlugin(['color-brand'])]
  );
  expect(actual).toMatchSnapshot();
});

it('nested functions', () => {
  const actual = runPlugins(
    `
    padding: rgba($color-brand, hsla($color-brand));
  `,
    [functionPlugin(['color-brand'])]
  );
  expect(actual).toMatchSnapshot();
});
