/* eslint-env jest */

const { runPlugins } = require('./helpers');

const varPlugin_ = require('../var');
const varPlugin = x =>
  varPlugin_(x, { transform: x => `token(${x})` });

it('replaces valid token within single fallback', () => {
  const actual = runPlugins(
    `
    background: var(--sds-c-icon-color-background, $color-brand);
  `,
    [varPlugin(['color-brand'])]
  );
  expect(actual).toMatchSnapshot();
});

it('ignores non-token variable within single fallback', () => {
  const actual = runPlugins(
    `
    @each $name, $color in $bg-actions-map {

      .slds-icon-#{$name} {
        background-color: var(--sds-c-icon-color-background, $color);
      }
    }
  `,
    [varPlugin([])]
  );
  expect(actual).toMatchSnapshot();
});

it('replaces valid token within multiple css var statements', () => {
  const actual = runPlugins(
    `
    padding: var(--sds-c-button-padding-vertical, $spacing-small) var(--sds-c-button-padding-horizontal, $spacing-large);
  `,
    [varPlugin(['spacing-small', 'spacing-large' ])]
  );
  expect(actual).toMatchSnapshot();
});

it('replaces valid token within nested var statements', () => {
  const actual = runPlugins(
    `
    .slds-card__header {
      /* double fallback */
      padding-top: var(--sds-c-card-header-spacing-block-start, var(--sds-c-card-header-spacing-block, $var-spacing-vertical-small));
      /* triple fallback */
      padding-right: var(--foo, var(--sds-c-card-header-spacing-inline-end, var(--sds-c-card-header-spacing-inline, $var-spacing-horizontal-medium)));
    }
  `,
    [varPlugin(["var-spacing-vertical-small", "var-spacing-horizontal-medium"])]
  );
  expect(actual).toMatchSnapshot();
});

it('replaces interpolated sass var as valid token within nested var statements', () => {
  const actual = runPlugins(
    `
    .slds-card__header {
      /* single fallback */
      --slds-c-button-color-background: var(--sds-c-button-neutral-color-background, #{$color-brand});
      /* double fallback */
      --slds-c-button-color-background: var(--slds-c-button-neutral-color-background, var(--sds-c-button-neutral-color-background, #{$color-brand}));
      /* triple fallback */
      --slds-c-button-color-background: var(--foo, var(--slds-c-button-neutral-color-background, var(--sds-c-button-neutral-color-background, #{$color-brand})));
    }
  `,
    [varPlugin(['color-brand'])]
  );
  expect(actual).toMatchSnapshot();
});

it('replaces valid token within css var assignment with var function value', () => {
  const actual = runPlugins(
    `
    .a { --sds-c-icon-color-background: var(--sds-c-icon-color-background, #{$color-brand}); }
  `,
    [varPlugin(['color-brand'])]
  );
  expect(actual).toMatchSnapshot();
});

it('replaces valid token within css var assignment with var function value with other interpolations', () => {
  const actual = runPlugins(
    `
    .a { --sds-c-button-spacing-horizontal-start: var(--sds-c-button-#{$api-variant}-spacing-horizontal-start, #{$spacing-medium}); }
  `,
    [varPlugin(['spacing-medium'])]
  );
  expect(actual).toMatchSnapshot();
});

it('removes interpolation inside var', () => {
  const actual = runPlugins(
    `
    padding: var(--custom-property, #{$color-brand});
  `,
    [varPlugin(['color-brand'])]
  );
  expect(actual).toEqual(
    `
    padding: token("var(--custom-property, "+#{colorBrand}+")");
  `);
});

it('removes interpolation inside custom property reassignment', () => {
  const actual = runPlugins(
    `
    --custom-property-1: var(--custom-property-2, #{$color-brand});
  `,
    [varPlugin(['color-brand'])]
  );
  expect(actual).toEqual(
    `
    --custom-property-1: token("var(--custom-property-2, "+#{colorBrand}+")");
  `);
});